@@ -14,7 +14,6 @@ pygtk.require('2.0')
 import gtk
 import gtk.glade
 import gobject
-import glib
 from pkg_resources import load_entry_point
 
 class DeckenGUI:
@@ -132,7 +131,7 @@ class DeckenGUI:
 		caminho = self.plugin.find_or_create_path(self.path_image, card)
 		try:
 			pixbuf = gtk.gdk.pixbuf_new_from_file(caminho)
-		except glib.GError:
+		except:
 			self.plugin.download_image(card, caminho)
 			pixbuf = gtk.gdk.pixbuf_new_from_file(caminho)
 		pixbuf = pixbuf.scale_simple(312,445,gtk.gdk.INTERP_BILINEAR)
